EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_CreateOrUpdateReleaseDeployable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets the furthest build number for the release.'
GO


IF OBJECT_ID('[Releases_CreateOrUpdateReleaseDeployable]') IS NOT NULL DROP PROCEDURE [Releases_CreateOrUpdateReleaseDeployable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_CreateOrUpdateReleaseDeployable]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Deployable_Id INT,
	@Referenced_Application_Id INT,
	@Referenced_Release_Number RELEASENUMBER
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Release_Id INT
	SELECT @Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

	DECLARE @Referenced_Release_Id INT
	SELECT @Referenced_Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = COALESCE(@Referenced_Application_Id, @Application_Id)
	   AND [Release_Number] = @Referenced_Release_Number

	IF EXISTS(SELECT * FROM [ReleaseDeployables] WHERE [Release_Id] = @Release_Id AND [Deployable_Id] = @Deployable_Id)
	BEGIN

		UPDATE [ReleaseDeployables]
		   SET [InclusionType_Code] = CASE WHEN @Referenced_Release_Id IS NULL THEN 'I' ELSE 'R' END,
		       [Referenced_Release_Id] = @Referenced_Release_Id
		 WHERE [Release_Id] = @Release_Id
		   AND [Deployable_Id] = @Deployable_Id

	END
	ELSE
	BEGIN

		INSERT INTO [ReleaseDeployables]
		(
			[Release_Id],
			[Deployable_Id],
			[InclusionType_Code],
			[Referenced_Release_Id]
		)
		VALUES
		(
			@Release_Id,
			@Deployable_Id,
			CASE WHEN @Referenced_Release_Id IS NULL THEN 'I' ELSE 'R' END,
			@Referenced_Release_Id
		)

	END

	COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Releases_CreateOrUpdateReleaseDeployable] TO [BuildMasterUser_Role]
